randomDNASequences <- function(n, w)
{
  alphabet <- c("A", "T", "G", "C")
  w <- rep(w, length=n)
  sequences <- sapply(seq(1, n, length=n),
                      function(x) {
                        s <- sample(alphabet, w[x], replace=TRUE)
                        s <- paste(s, collapse="")
                        return(s)
                      })
  return(Biostrings::DNAStringSet(sequences))
}

tilingIRanges <- function(width, step, from, to) {

  if (to < from) {
    stop("'to' must be > 'from'")
  }
  chunk <- to - from
  n <- (chunk - width) %/% step
  gapwidth <- rep(step - width, n)
  width <- rep(width, n+1)
  successiveIRanges(width, gapwidth, from = from)
}

msubseq <- function(x, ir)
{
  ## differs from subseq in the sense that several subsequences
  ## from the same sequence are extracted
  ## x:  XString
  ## ir: IRanges
  res <- vector("character", length = length(ir))
  for (i in seq(along=res)) {
    res[i] <- as.character(subseq(x, start=ir@start[i], width=width(ir)[i]))
    ## forced cast: chain of tools for DNAString seems interupted compared
    ##              to having strings.
  }
  res <- Biostrings::DNAStringSet(res)
  return(res)
}

randomIRanges <- function(n, width, from, to, replace=TRUE)
{
  if (from+width >= to) {
    stop("'from' + 'width' should be < 'to'.")
  }
  start <- sample(from:(to-width), n, replace=replace)
  res <- IRanges(start=start, width=width)
  return(res)
}


tilingProbes <- function(width, step, template_seq)
{
  tir <- tilingIRanges(width, step, 1, nchar(template_seq))
  tip <- msubseq(template_seq, tir)
  return(tip)
}

